audiod: fix enum of supported audio formats
[paraslash.git] / time.c
diff --git a/time.c b/time.c
index 34e3de9523cb91a6c4142cf36ec6d540d21d7fe6..83231c895020245d72cea40cd34cae03e9951a29 100644 (file)
--- a/time.c
+++ b/time.c
@@ -106,16 +106,23 @@ void tv_scale(const unsigned long mult, const struct timeval *tv,
 /**
  * compute fraction of given struct timeval
  *
* \param div the integer value to divide by
  * \param tv the timevalue to divide
  * \param result holds (1 / mult) * tv upon return
  */
-void tv_divide(const unsigned long div, const struct timeval *tv,
+void tv_divide(const unsigned long divisor, const struct timeval *tv,
        struct timeval *result)
 {
-       long unsigned q = tv->tv_usec / div;
-       result->tv_sec = tv->tv_sec / div;
-       result->tv_usec = (tv->tv_sec - result->tv_sec * div) * 1000 * 1000 / div;
+       long unsigned q;
+
+       if (!divisor) {
+               PARA_EMERG_LOG("%s\n", "division by zero");
+               exit(EXIT_FAILURE);
+       }
+       q = tv->tv_usec / divisor;
+       result->tv_sec = tv->tv_sec / divisor;
+       result->tv_usec = (tv->tv_sec - result->tv_sec * divisor)
+               * 1000 * 1000 / divisor;
        if (result->tv_usec + q >= 1000 * 1000) {
                result->tv_sec++;
                result->tv_usec = 1000 * 1000 - result->tv_usec - q;
@@ -106,16 +106,23 @@ void tv_scale(const unsigned long mult, const struct timeval *tv,
  * compute fraction of given struct timeval
  *
- * \param div the integer value to divide by
+ * \param divisor the integer value to divide by
  * \param tv the timevalue to divide
  * \param result holds (1 / mult) * tv upon return